summaryrefslogtreecommitdiffstats
path: root/core/js/js.js
diff options
context:
space:
mode:
authorJan-Christoph Borchardt <hey@jancborchardt.net>2016-11-24 16:05:05 +0100
committerJan-Christoph Borchardt <hey@jancborchardt.net>2016-11-24 16:05:05 +0100
commite75dede5905c3c796ca1c9d71e3ff61facf4ba56 (patch)
tree4b4b753b26d36b6917cd3630d762e9a44b8ffd92 /core/js/js.js
parentd6ade509cf33849edb10b33fb2490b2428f9091b (diff)
downloadnextcloud-server-e75dede5905c3c796ca1c9d71e3ff61facf4ba56.tar.gz
nextcloud-server-e75dede5905c3c796ca1c9d71e3ff61facf4ba56.zip
fix some outdated naming
Signed-off-by: Jan-Christoph Borchardt <hey@jancborchardt.net>
Diffstat (limited to 'core/js/js.js')
-rw-r--r--core/js/js.js18
1 files changed, 9 insertions, 9 deletions
diff --git a/core/js/js.js b/core/js/js.js
index 714529fe5d1..b8535518f02 100644
--- a/core/js/js.js
+++ b/core/js/js.js
@@ -69,8 +69,8 @@ var OCP = {},
TAG_FAVORITE: '_$!<Favorite>!$_',
/* jshint camelcase: false */
/**
* Relative path to ownCloud root.
* For example: "/owncloud"
*
* @type string
*
@@ -240,7 +240,7 @@ var OCP = {},
},
/**
* Protocol that is used to access this ownCloud instance
* @return {string} Used protocol
*/
getProtocol: function() {
@@ -248,7 +248,7 @@ var OCP = {},
},
/**
* Returns the host used to access this ownCloud instance
* Host is sometimes the same as the hostname but now always.
*
* Examples:
@@ -265,7 +265,7 @@ var OCP = {},
},
/**
* Returns the hostname used to access this ownCloud instance
* The hostname is always stripped of the port
*
* @return {string} hostname
@@ -276,7 +276,7 @@ var OCP = {},
},
/**
* Returns the port number used to access this ownCloud instance
*
* @return {int} port number
*
@@ -287,9 +287,9 @@ var OCP = {},
},
/**
* Returns the web root path where this ownCloud instance
* is accessible, with a leading slash.
- * For example "/owncloud".
+ * For example "/nextcloud".
*
* @return {string} web root path
*
@@ -1404,7 +1404,7 @@ function initCore() {
// move triangle of apps dropdown to align with app name triangle
// 2 is the additional offset between the triangles
if($('#navigation').length) {
- $('#header #owncloud + .menutoggle').one('click', function(){
+ $('#header #nextcloud + .menutoggle').one('click', function(){
var caretPosition = $('.header-appname + .icon-caret').offset().left - 2;
if(caretPosition > 255) {
// if the app name is longer than the menu, just put the triangle in the middle
@@ -69,8 +69,8 @@ var OCP = {},
/* jshint camelcase: false */
/**
- * Relative path to ownCloud root.
- * For example: "/owncloud"
+ * Relative path to Nextcloud root.
+ * For example: "/nextcloud"
*
* @type string
@@ -240,7 +240,7 @@ var OCP = {},
},
/**
- * Protocol that is used to access this ownCloud instance
+ * Protocol that is used to access this Nextcloud instance
* @return {string} Used protocol
*/
@@ -248,7 +248,7 @@ var OCP = {},
},
/**
- * Returns the host used to access this ownCloud instance
+ * Returns the host used to access this Nextcloud instance
* Host is sometimes the same as the hostname but now always.
*
@@ -265,7 +265,7 @@ var OCP = {},
},
/**
- * Returns the hostname used to access this ownCloud instance
+ * Returns the hostname used to access this Nextcloud instance
* The hostname is always stripped of the port
*
@@ -276,7 +276,7 @@ var OCP = {},
},
/**
- * Returns the port number used to access this ownCloud instance
+ * Returns the port number used to access this Nextcloud instance
*
* @return {int} port number
@@ -287,9 +287,9 @@ var OCP = {},
},
/**
- * Returns the web root path where this ownCloud instance
+ * Returns the web root path where this Nextcloud instance
* is accessible, with a leading slash.